@@ -17,6 +17,7 @@ def get_db() -> sqlite3.Connection:
     if 'db' not in g or not isinstance(g.db, sqlite3.Connection):
         g.db = sqlite3.connect(current_app.instance_resource('whisper.db'))
         g.db.row_factory = sqlite3.Row
+        g.db.execute('PRAGMA foreign_keys = ON')
         current_app.e('core:db_connect')
     return g.db
 
@@ -37,8 +38,9 @@ def init_db() -> None:
         current_app.logger.warning('whisper.db not found! initializing...')
         if os.path.exists(db_file):
             raise IsADirectoryError(f'{db_file} is a directory')
-        with current_app.open_resource(
-            os.path.join('core', 'schema.sql'),
-            'r'
+        with open(
+            current_app.app_resource('core', 'schema.sql'),
+            'r',
+            encoding='utf-8',
         ) as f:
             current_app.db.executescript(f.read())
